@@ -19,12 +19,12 @@ import os
 import os.path
 
 PACKAGE    = "sabayon"
-VERSION    = "2.20.1"
-LOCALEDIR = "/usr/local/share/locale"
-DATADIR    = "/usr/local/share"
-SYSCONFDIR = "/usr/local/etc"
-LIBEXECDIR = "/usr/local/libexec"
-SBINDIR    = "/usr/local/sbin"
+VERSION    = "2.22.1"
+LOCALEDIR = "/gnome/releases/usr/share/locale"
+DATADIR    = "/gnome/releases/usr/share"
+SYSCONFDIR = "/gnome/releases/usr/etc"
+LIBEXECDIR = "/gnome/releases/usr/libexec"
+SBINDIR    = "/gnome/releases/usr/sbin"
 
 GLADEDIR    = os.path.join (DATADIR, "sabayon", "glade")
 PROFILESDIR = os.path.join (SYSCONFDIR, "desktop-profiles")
@@ -93,16 +93,18 @@ FILES_TO_IGNORE = [
     ".gnome2/share/cursor-fonts/fonts.dir",
     ".gnome2/share/fonts/fonts.dir",
     ".gtkrc-1.2-gnome2*",
-    ".recently-used",
-    ".xsession-errors",
-    ".local",
-    ".config"
+    ".pulse-cookie",
+    ".recently-used*",
+    ".xsession-errors"
 ]
 
 #
 # Directories which we don't want to see change notifications for
 # 
 DIRECTORIES_TO_IGNORE = [
+    ".beagle",
+    ".cache",
+    ".fontconfig",
     ".gconf",
     ".gconf.xml.defaults",
     ".gconf.xml.mandatory",
@@ -115,8 +117,7 @@ DIRECTORIES_TO_IGNORE = [
     ".profile_cache",
     ".thumbnails",
     ".wapi",
-    ".fontconfig",
-    ".beagle"
+    ".Trash"
 ]
 
 #
