@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 #
 # Copyright (C) 2005 Red Hat, Inc.
 #
@@ -21,14 +19,16 @@
 import os
 import os.path
 import sys
+import pygtk; pygtk.require('2.0');
 import gobject
 from config import *
 import storage
 import traceback
 import util
+import debuglog
 
 def dprint (fmt, *args):
-    util.debug_print (util.DEBUG_USERPROFILE, fmt % args)
+    debuglog.debug_log (False, debuglog.DEBUG_LOG_DOMAIN_USER_PROFILE, fmt % args)
 
 class ModuleLoader:
     """Loads all python modules from a directory allows objects
@@ -45,7 +45,7 @@ class ModuleLoader:
 
     def __load_module (self, module):
         """Load a python module named @module."""
-        dprint ("Loading module: %s" % module)
+        dprint ("Loading module: %s", module)
         cmd = "from sources import %s" % module
         try:
             exec (cmd)
@@ -57,7 +57,7 @@ class ModuleLoader:
         
     def __load_modules (self):
         """Load all available modules from self.module_path."""
-        dprint ("Loading modules from %s" % self.module_path)
+        dprint ("Loading modules from %s", self.module_path)
         sys.path.append (self.module_path)
         for file in os.listdir (self.module_path):
             if file[0] == '.':
@@ -72,7 +72,7 @@ class ModuleLoader:
         """Construct an object by invoking a function named @constructor,
         with @arg as an argument, in the module called @module.
         """
-        dprint ("Constructing object from loaded module using %s.%s" % (module, constructor))
+        dprint ("Constructing object from loaded module using %s.%s", module, constructor)
         cmd = ("from sources import %s\n"
                "if %s.__dict__.has_key ('%s'):"
                "    ret = %s.%s (arg)") % (module, module, constructor, module, constructor)
@@ -134,6 +134,18 @@ class ProfileChange (gobject.GObject):
         """Return a short description of the configuration change."""
         raise Exception ("Not implemented")
 
+    def get_ignore_default (self):
+        """Returns the default value for the ignore item for this change."""
+        return False;
+        
+    def get_mandatory (self):
+        """Returns the mandatory value of the change, or None to use the default"""
+        return None
+
+    def merge_old_change (self, old_change):
+        """Merges info from previous change into this change. Return True to discard the new change."""
+        return False
+
 gobject.type_register (ProfileChange)
 
 class SourceDelegate:
@@ -157,6 +169,13 @@ class SourceDelegate:
         """Returns the configuration delegate's name."""
         return self.name
 
+    def get_path_description (self, path):
+        """Returns a human readable description for @path.
+        @path must have been previously added by the delegate to the
+        #ProfileStorage.
+        """
+        return path
+    
     def handle_change (self, change):
         """Inspect a ProfileChange. Return #True if the change should
         not be passed on any further (i.e. #True == 'handled') and
@@ -184,7 +203,11 @@ class SourceDelegate:
         """Save all committed changes to disk."""
         raise Exception ("Not implemented")
 
-    def apply (self):
+    def set_enforce_mandatory (self, enforce):
+        """Temporary make mandatory setting non-mandatory."""
+        raise Exception ("Not implemented")
+
+    def apply (self, is_sabayon_session):
         """Apply profile to the current user's environment."""
         raise Exception ("Not implemented")
     
@@ -207,6 +230,13 @@ class ProfileSource (gobject.GObject):
         if delegate_constructor:
             self.delegates = module_loader.construct_objects (delegate_constructor, self)
     
+    def get_delegate (self, delegate_name):
+        """Return a delegate named @delegate_name."""
+        for delegate in self.delegates:
+            if delegate.get_name () == delegate_name:
+                return delegate
+        return None
+
     def get_name (self):
         """Returns the configuration source's name."""
         return self.name
@@ -227,7 +257,7 @@ class ProfileSource (gobject.GObject):
             if not change.get_id ().startswith (delegate.namespace_section):
                 continue
             if delegate.handle_change (change):
-                dprint ("Delegate '%s' handled change '%s'" % (delegate.get_name (), change.get_id ()))
+                dprint ("Delegate '%s' handled change '%s'", delegate.get_name (), change.get_id ())
                 return
         self.emit ("changed", change)
         
@@ -239,7 +269,7 @@ class ProfileSource (gobject.GObject):
         """
         if change.delegate:
             change.delegate.commit_change (change, mandatory)
-            dprint ("Delegate '%s' committed changes '%s'" % (change.delegate.get_name (), change.get_id ()))
+            dprint ("Delegate '%s' committed changes '%s'", change.delegate.get_name (), change.get_id ())
             return True
         return False
     
@@ -255,7 +285,11 @@ class ProfileSource (gobject.GObject):
         """Save all committed changes to disk."""
         raise Exception ("Not implemented")
 
-    def apply (self):
+    def set_enforce_mandatory (self, enforce):
+        """Temporary make mandatory setting non-mandatory."""
+        raise Exception ("Not implemented")
+    
+    def apply (self, is_sabayon_session):
         """Apply profile to the current user's environment."""
         raise Exception ("Not implemented")
 
@@ -271,28 +305,28 @@ class UserProfile (gobject.GObject):
     def __init__ (self, profile_name):
         """Construct a UserProfile
 
-	profile_name: name of the profile to be loaded
+        profile_name: name of the profile to be loaded
         module_path: optional path from which configuration modules
         should be loaded
         """
         gobject.GObject.__init__ (self)
 
-        dprint ("Constructing profile from %s" % profile_name)
+        dprint ("Constructing profile from %s", profile_name)
 
         self.profile_name = profile_name
 
         #
-	# Open the user settings packages and try to install them
-	#
-	self.storage = storage.ProfileStorage (profile_name)
+        # Open the user settings packages and try to install them
+        #
+        self.storage = storage.ProfileStorage (profile_name)
         
         module_loader = get_module_loader ()
         
         self.sources = []
         self.sources = module_loader.construct_objects ("get_source", self.storage)
-        dprint ("%d sources loaded:" % len (self.sources))
+        dprint ("%d sources loaded:", len (self.sources))
         for source in self.sources:
-            dprint ("  %s" % source.get_name ())
+            dprint ("  %s", source.get_name ())
             source.connect ("changed", self.__handle_source_changed)
 
     def __handle_source_changed (self, source, change):
@@ -305,13 +339,24 @@ class UserProfile (gobject.GObject):
                 return source
         return None
 
+    def get_delegate (self, delegate_name):
+        """Return a delegate named @delegate_name."""
+        for source in self.sources:
+            delegate = source.get_delegate (delegate_name)
+            if not delegate is None:
+                return delegate
+        return None
+
     def start_monitoring (self):
         """Start monitoring for configuration changes."""
         dprint ("Starting monitoring")
         for s in self.sources:
+            # Start source monitor before delegates so we
+            # can e.g. set up gconf in the gconf source and
+            # use it in the gconf delegate
+            s.start_monitoring ()
             for delegate in s.delegates:
                 delegate.start_monitoring ()
-            s.start_monitoring ()
 
     def stop_monitoring (self):
         """Stop monitoring for configuration changes."""
@@ -330,13 +375,21 @@ class UserProfile (gobject.GObject):
             s.sync_changes ()
         self.storage.save ()
 
-    def apply (self):
+    def set_enforce_mandatory (self, enforce):
+        """Temporary make mandatory setting non-mandatory."""
+        dprint ("Changing mandatory enforcement in user's environment")
+        for s in self.sources:
+            s.set_enforce_mandatory (enforce)
+            for delegate in s.delegates:
+                delegate.set_enforce_mandatory (enforce)
+    
+    def apply (self, is_sabayon_session):
         """Apply profile to the current user's environment."""
         dprint ("Applying profile to user's environment")
         for s in self.sources:
-            s.apply ()
+            s.apply (is_sabayon_session)
             for delegate in s.delegates:
-                delegate.apply ()
+                delegate.apply (is_sabayon_session)
 
 gobject.type_register (UserProfile)
 
