@@ -19,6 +19,7 @@
 import os
 import os.path
 import sys
+import fnmatch
 import pwd
 import gettext
 import locale
@@ -30,6 +31,7 @@ from config import *
 EXIT_CODE_NORMAL = 0
 EXIT_CODE_FATAL = 1
 EXIT_CODE_RECOVERABLE = 2
+EXIT_CODE_NO_USER_PROFILE = 3 # only for sabayon-apply
 
 _util_admin_log_config_filename = None
 _util_readable_log_config_filename = None
@@ -84,7 +86,7 @@ def get_home_dir ():
             return pw.pw_dir
     except KeyError:
         pass
-    
+
     if os.environ.has_key ("HOME"):
         return os.environ["HOME"]
     else:
@@ -97,7 +99,7 @@ def get_user_name ():
             return pw.pw_name
     except KeyError:
         pass
-    
+
     if os.environ.has_key ("USER"):
         return os.environ["USER"]
     else:
@@ -110,11 +112,15 @@ def print_exception ():
 
 def init_gettext ():
     """Binds _() to gettext.gettext() in the global namespace. Run
-    util.init_gettext() at the entry point to any script and you'll
-    be able to use _() to mark strings for translation.
-    """
+    util.init_gettext() at the entry point to any script and you'll be
+    able to use _(), gettext(), and ngettext() to mark strings for
+    translation."""
     locale.setlocale (locale.LC_ALL, "")
     gettext.install (PACKAGE, LOCALEDIR)
+    # Python 2.4 compatibility
+    import __builtin__
+    __builtin__.__dict__['gettext'] = __builtin__.__dict__['_']
+    __builtin__.__dict__['ngettext'] = gettext.ngettext
 
 def random_string (len):
     """Returns a string with random binary data of the specified length"""
@@ -161,7 +167,7 @@ def split_path(path, head=None, tail=None):
         if path[dir_split] != '/':
             raise ValueError
         return (path[:dir_split], path[dir_split+1:])
-        
+
     raise ValueError
 
 #
@@ -179,7 +185,7 @@ def uninterruptible_spawnve (mode, file, args, env):
     except os.error, (err, errstr):
         if err != errno.EINTR:
             raise
-        
+
 def uninterruptible_spawnv (mode, file, args):
     uninterruptible_spawnve (mode, file, args, None)
 
@@ -211,7 +217,7 @@ class DictCompare:
 
         self.keys_a = self.a.keys()
         self.keys_b = self.b.keys()
-        
+
         self.intersection = []
         self.only_a = []
         self.only_b = []
@@ -230,13 +236,13 @@ class DictCompare:
         for k in self.keys_b:
             if not self.a.has_key(k):
                 self.only_b.append(k)
-                
+
         for k in self.intersection:
             if self.a[k] == self.b[k]:
                 self.equal.append(k)
             else:
                 self.not_equal.append(k)
-                
+
     def intersection(self):
         'return list of keys shared between a and b'
         return self.intersection
@@ -262,7 +268,7 @@ class DictCompare:
         (e.g. lhs = rhs), the two dictionary parameters are specified as
         either the string 'a' or the string 'b' corresponding to the parameters
         this class was created with.
-        
+
         Return value is a dictionary with 3 keys (add, del, mod) whose values
         are dictionaries containing containing (key,value) pairs to add,
         delete, or modify respectively in dict_lhs.'''
@@ -334,3 +340,28 @@ def dump_change_set(cs):
             print "    %s=%s" % (k, _mod[k])
 
 
+def should_ignore_dir (base_dir, ignore_dir_list, dir):
+    dir = os.path.normpath (dir)
+
+    for ignore_dir in ignore_dir_list:
+        ignore_path = os.path.normpath (os.path.join (base_dir, ignore_dir))
+
+        if fnmatch.fnmatch (dir, ignore_path):
+            return True
+
+    parent = os.path.dirname (dir)
+    if parent != dir:
+        return should_ignore_dir (base_dir, ignore_dir_list, parent)
+    else:
+        return False
+
+def should_ignore_file (base_dir, ignore_dir_list, ignore_file_list, file):
+    file = os.path.normpath (file)
+
+    for ignore_file in ignore_file_list:
+        ignore_path = os.path.normpath (os.path.join (base_dir, ignore_file))
+
+        if fnmatch.fnmatch (file, ignore_path):
+            return True
+
+    return should_ignore_dir (base_dir, ignore_dir_list, os.path.dirname (file))
